@@ -1,5 +1,5 @@
 #PySciTrivia
-#Copyright 2005, Michael Atkinson
+#Copyright (C) 2005, 2006 Michael Atkinson
 
 #This file is part of PySciTrivia.
 
@@ -17,35 +17,24 @@
 #along with PySciTrivia; if not, write to the Free Software
 #Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-#import python modules
 import os, sys, pygame, random, math
 from pygame.locals import *
 
-#import resolution from scale
-from scale import res
+from scale import res, cs
+from scale import itemfont, scorefont, numfont, questionfont, title2font
+from scale import bgcolor, boxcolor, numcolor, itemcolor, item2color, wrongcolor, correctcolor, shcolor, alpha, titlecolor
 from text_wrap import TextWrap
 from set_category import SetQuestion
 from esc import Esc
 
 #set some things according to resolution
-questionfontsize = int(.0325*res[0])
-itemfontsize = numfontsize= int(0.041*res[0])
-scorefontsize = int(0.0275*res[0])
-itemspacing_y = int(.09*res[1])
 numshift = int(.0625*res[0])
 itemshift = 2*numshift
-qshift_x = int(0.03125*res[0])
+qshift = int(0.03125*res[0])
 scorespacing = int(.06*res[1])
-
-#colors
-white = (255,255,255)
-black = (0,0,0)
-yellow = (251,254,0)
-blue = (0,160,255)
-green = (0,254,17)
-green2 = (5,240,30)
-teal = (0,255,255)
-red = (255,0,0)
+scoreshift = int(.1*res[0])
+timeshift = int(.05*res[0])
+itemspacing = int(.09*res[1])
 
 #set bindings for player buzzers
 inputfile = open('settings/input.txt', 'r')
@@ -58,34 +47,27 @@ inputfile.close()
 buzz = pygame.mixer.Sound("data/sounds/effects/buzz.ogg")
 correct = pygame.mixer.Sound("data/sounds/effects/correct.ogg")
 wrong = pygame.mixer.Sound("data/sounds/effects/wrong.ogg")
-
-#initialize pygame
-pygame.init()
+tick = pygame.mixer.Sound("data/sounds/effects/tick.ogg")
+tock = pygame.mixer.Sound("data/sounds/effects/tock.ogg")
 
 class MakeQuestion:
-	def __init__(self, screen, background, question, choice1, choice2, choice3, choice4, sound, numplayers):
+	def __init__(self, screen, background, question, choice1, choice2, choice3, choice4, sound, numplayers, roundnum):
 		self.screen = screen; self.background = background
 		self.question = question
 		self.sound = sound
 		self.choice1 = choice1; self.choice2 = choice2; self.choice3 = choice3; self.choice4 = choice4
 		self.numplayers = numplayers
 		
-		#fonts
-		self.questionfont = pygame.font.Font('data/fonts/FreeSansBold.ttf', questionfontsize)
-		self.itemfont = pygame.font.Font('data/fonts/FreeSansBold.ttf', itemfontsize)
-		self.numfont = pygame.font.Font('data/fonts/FreeSansBold.ttf', numfontsize)
-		self.scorefont = pygame.font.Font('data/fonts/FreeSansBold.ttf', scorefontsize)
-		
-		#surfaces
-		self.num1 = self.numfont.render("1", 1, yellow)
-		self.num2 = self.numfont.render("2", 1, yellow)
-		self.num3 = self.numfont.render("3", 1, yellow)
-		self.num4 = self.numfont.render("4", 1, yellow)
-		self.item1 = self.itemfont.render(self.choice1, 1, green2)
-		self.item2 = self.itemfont.render(self.choice2, 1, green2)
-		self.item3 = self.itemfont.render(self.choice3, 1, green2)
-		self.item4 = self.itemfont.render(self.choice4, 1, green2)
-		#rects
+		#create surfaces
+		self.num1 = numfont.render("1", 1, numcolor)
+		self.num2 = numfont.render("2", 1, numcolor)
+		self.num3 = numfont.render("3", 1, numcolor)
+		self.num4 = numfont.render("4", 1, numcolor)
+		self.item1 = itemfont.render(self.choice1, 1, itemcolor)
+		self.item2 = itemfont.render(self.choice2, 1, itemcolor)
+		self.item3 = itemfont.render(self.choice3, 1, itemcolor)
+		self.item4 = itemfont.render(self.choice4, 1, itemcolor)
+		#create rects
 		self.num1rect = self.num1.get_rect()
 		self.num2rect = self.num2.get_rect()
 		self.num3rect = self.num3.get_rect()
@@ -96,20 +78,20 @@ class MakeQuestion:
 		self.item4rect = self.item4.get_rect()
 		#move rects
 		self.num1rect.centery = screen.get_rect().centery
-		self.num2rect.top = self.num1rect.top + itemspacing_y
-		self.num3rect.top = self.num2rect.top + itemspacing_y
-		self.num4rect.top = self.num3rect.top + itemspacing_y
+		self.num2rect.top = self.num1rect.top + itemspacing
+		self.num3rect.top = self.num2rect.top + itemspacing
+		self.num4rect.top = self.num3rect.top + itemspacing
 		self.num1rect.left = self.num2rect.left = self.num3rect.left = self.num4rect.left =  self.num2rect.left + numshift
-		self.item1rect.centery = screen.get_rect().centery
-		self.item2rect.top = self.item1rect.top + itemspacing_y
-		self.item3rect.top = self.item2rect.top + itemspacing_y
-		self.item4rect.top = self.item3rect.top + itemspacing_y
+		self.item1rect.centery = self.num1rect.centery
+		self.item2rect.centery = self.num2rect.centery
+		self.item3rect.centery = self.num3rect.centery
+		self.item4rect.centery = self.num4rect.centery
 		self.item1rect.left = self.item2rect.left = self.item3rect.left = self.item4rect.left = self.item1rect.left + itemshift
 		
-		#textwrap 
-		self.tw = TextWrap(screen, background, self.question, self.questionfont)
-		self.tw.line1rect.top = self.tw.line1rect.top + qshift_x
-		self.tw.line1rect.left = self.tw.line1rect.left + qshift_x
+		#question textwrap
+		self.tw = TextWrap(screen, background, self.question, questionfont)
+		self.tw.line1rect.top = self.tw.line1rect.top + qshift*2
+		self.tw.line1rect.left = self.tw.line1rect.left + qshift
 		if len(self.tw.q2) >= 1:
 			self.tw.line2rect.top = self.tw.line1rect.bottom
 			self.tw.line2rect.left = self.tw.line1rect.left
@@ -125,6 +107,12 @@ class MakeQuestion:
 		if len(self.tw.q6) >= 1:
 			self.tw.line6rect.top = self.tw.line5rect.bottom
 			self.tw.line6rect.left = self.tw.line1rect.left
+			
+		roundstring = "Round " + str(roundnum)
+		self.round = title2font.render(roundstring, 1, titlecolor)
+		self.roundrect = self.round.get_rect()
+		self.roundrect.top = self.screen.get_rect().top + self.roundrect.h*(.1)
+		self.roundrect.right = self.screen.get_rect().right - self.roundrect.h*(.1)
 	
 	def drawscreen(self):
 		self.screen.blit(self.tw.line1, self.tw.line1rect)
@@ -139,83 +127,91 @@ class MakeQuestion:
 			self.screen.blit(self.tw.line5, self.tw.line5rect)
 		if len(self.tw.q6) >= 1:
 			self.screen.blit(self.tw.line6, self.tw.line6rect)
-		#blit the numbers and possible answers
+		#blit numbers and choices
 		self.screen.blit(self.num1, self.num1rect); self.screen.blit(self.item1, self.item1rect)
 		self.screen.blit(self.num2, self.num2rect); self.screen.blit(self.item2, self.item2rect)
 		self.screen.blit(self.num3, self.num3rect); self.screen.blit(self.item3, self.item3rect)
 		self.screen.blit(self.num4, self.num4rect); self.screen.blit(self.item4, self.item4rect)
 		
+		self.screen.blit(self.round, self.roundrect)
+		
+		
 	def drawselection(self, pos):
-		self.selectionrect = self.num1.get_rect()
+		self.selectionrect = self.item1.get_rect()
 		background2 = pygame.Surface((res[0], self.selectionrect.height))
-		background2.set_alpha(100)
-		background2.fill(blue)
-		self.selectionrect.centery = self.num1rect.centery + itemspacing_y*(pos - 1)
+		background2.set_alpha(alpha)
+		background2.fill(boxcolor)
+		self.selectionrect.centery = self.num1rect.centery + itemspacing*(pos - 1)
 		self.screen.blit(background2, self.selectionrect)
 	
 	def drawcorrect(self, pos):
-		self.selectionrect3 = self.num1.get_rect()
+		self.selectionrect3 = self.item1.get_rect()
 		background2 = pygame.Surface((res[0], self.selectionrect3.height))
-		background2.set_alpha(100)
-		background2.fill(teal)
-		self.selectionrect3.centery = self.num1rect.centery + itemspacing_y*(pos - 1)
+		background2.set_alpha(alpha)
+		background2.fill(correctcolor)
+		self.selectionrect3.centery = self.num1rect.centery + itemspacing*(pos - 1)
 		self.screen.blit(background2, self.selectionrect3)
 	
 	def drawwrong(self, w1, w2, w3, w4):
-		self.selectionrect2 = self.num1.get_rect()
+		self.selectionrect2 = self.item1.get_rect()
 		background2 = pygame.Surface((res[0], self.selectionrect2.height))
-		background2.set_alpha(100)
-		background2.fill(red)
-		if w1 == "yes":
+		background2.set_alpha(alpha)
+		background2.fill(wrongcolor)
+		if w1 == 1:
 			pos = 1
-			self.selectionrect2.centery = self.num1rect.centery + itemspacing_y*(pos - 1)
+			self.selectionrect2.centery = self.num1rect.centery + itemspacing*(pos - 1)
 			self.screen.blit(background2, self.selectionrect2)
-		if w2 == "yes":
+		if w2 == 1:
 			pos = 2
-			self.selectionrect2.centery = self.num1rect.centery + itemspacing_y*(pos - 1)
+			self.selectionrect2.centery = self.num1rect.centery + itemspacing*(pos - 1)
 			self.screen.blit(background2, self.selectionrect2)
-		if w3 == "yes":
+		if w3 == 1:
 			pos = 3
-			self.selectionrect2.centery = self.num1rect.centery + itemspacing_y*(pos - 1)
+			self.selectionrect2.centery = self.num1rect.centery + itemspacing*(pos - 1)
 			self.screen.blit(background2, self.selectionrect2)
-		if w4 == "yes":
+		if w4 == 1:
 			pos = 4
-			self.selectionrect2.centery = self.num1rect.centery + itemspacing_y*(pos - 1)
+			self.selectionrect2.centery = self.num1rect.centery + itemspacing*(pos - 1)
 			self.screen.blit(background2, self.selectionrect2)
 			
 	def drawscore(self, p1, p2, p3, buzzed, who):
-		p1h = self.scorefont.render("Player 1", 1, white)
-		p2h = self.scorefont.render("Player 2", 1, white)
-		p3h = self.scorefont.render("Player 3", 1, white)	
-		if buzzed == "yes":
-			if who ==1: p1h = self.scorefont.render("Player 1", 1, yellow)
-			elif who ==2: p2h = self.scorefont.render("Player 2", 1, yellow)
-			elif who ==3: p3h = self.scorefont.render("Player 3", 1, yellow)
+		p1h = scorefont.render("Player 1", 1, itemcolor)
+		p2h = scorefont.render("Player 2", 1, itemcolor)
+		p3h = scorefont.render("Player 3", 1, itemcolor)
+		
+		if buzzed == 1:
+			if who ==1: p1h = scorefont.render("Player 1", 1, shcolor)
+			elif who ==2: p2h = scorefont.render("Player 2", 1, shcolor)
+			elif who ==3: p3h = scorefont.render("Player 3", 1, shcolor)
 		else: pass
-		p1text = self.scorefont.render(str(p1), 1, white)
-		p2text = self.scorefont.render(str(p2), 1, white)
-		p3text = self.scorefont.render(str(p3), 1, white)
+	
+		p1text = scorefont.render(str(p1), 1, itemcolor)
+		p2text = scorefont.render(str(p2), 1, itemcolor)
+		p3text = scorefont.render(str(p3), 1, itemcolor)
 		#create rects
 		self.p1hrect = p1h.get_rect(); self.p2hrect = p2h.get_rect(); self.p3hrect = p3h.get_rect()
 		p1box = p1text.get_rect(); p2box = p2text.get_rect(); p3box = p3text.get_rect()	
 		#move rects
 		self.p1hrect.top = self.p2hrect.top = self.p3hrect.top =  self.num4rect.bottom + (.5)*scorespacing
-		self.p2hrect.centerx = self.screen.get_rect().centerx
+		self.p2hrect.centerx = self.screen.get_rect().centerx - scoreshift
 		self.p1hrect.centerx = self.p2hrect.centerx - (.5)*(self.screen.get_rect().centerx)
 		self.p3hrect.centerx = self.p2hrect.centerx + (.5)*(self.screen.get_rect().centerx)
 		p1box.top = p2box.top = p3box.top = self.num4rect.bottom + 1.7*scorespacing
-		p2box.centerx = self.screen.get_rect().centerx
+		p2box.centerx = self.screen.get_rect().centerx - scoreshift
 		p1box.centerx = p2box.centerx - (.5)*(self.screen.get_rect().centerx)
 		p3box.centerx = p2box.centerx + (.5)*(self.screen.get_rect().centerx)
 		#blit the header and score rects
 		self.screen.blit(p1h, self.p1hrect); self.screen.blit(p1text, p1box)
-		if self.numplayers == "2":
+		if self.numplayers == 2:
+		#if 1 == 1:
 			self.screen.blit(p1h, self.p1hrect); self.screen.blit(p1text, p1box)
 			self.screen.blit(p2h, self.p2hrect); self.screen.blit(p2text, p2box)
-		if self.numplayers == "3":
+		if self.numplayers == 3:
+		#if 1 == 1:
 			self.screen.blit(p1h, self.p1hrect); self.screen.blit(p1text, p1box)
 			self.screen.blit(p2h, self.p2hrect); self.screen.blit(p2text, p2box)
 			self.screen.blit(p3h, self.p3hrect); self.screen.blit(p3text, p3box)
+	
 	def playquestion(self):
 		if self.sound != 0:
 			self.sound.play(0,0)
@@ -224,14 +220,33 @@ class MakeQuestion:
 		if self.sound!= 0:
 			self.sound.stop()
 			print "sound should stop"
-	
+	def showtime(self, t):
+		time_text = scorefont.render("Time", 1, itemcolor)
+		time_textrect = time_text.get_rect()
+		
+		t = t/1000
+		t = int(t)
+		if t <= 0:
+			time = scorefont.render("0", 1, itemcolor)
+		else:
+			time = scorefont.render(str(t), 1, itemcolor)
+		timerect = time.get_rect()
+		
+		time_textrect.top = self.num4rect.bottom + (.5)*scorespacing
+		time_textrect.right = self.screen.get_rect().right - timeshift
+		timerect.centerx = time_textrect.centerx
+		timerect.top = time_textrect.bottom
+		
+		self.screen.blit(time, timerect)
+		self.screen.blit(time_text, time_textrect)
+		
 class BuzzIn:
-	def __init__(self, screen, background, qobj, sq, wrong1, wrong2, wrong3, wrong4, p1s, p2s, p3s, buzz):
+	def __init__(self, screen, background, qobj, sq, wrong1, wrong2, wrong3, wrong4, p1s, p2s, p3s, buzz, timeleft):
 		self.escape = Esc(screen, background)
 		self.wrong1 = wrong1; self.wrong2 = wrong2; self.wrong3 = wrong3; self.wrong4 = wrong4
 		boxcounter = 1
 		self.score = 0
-		self.playerwas = ""
+		self.playerwas = 0
 		
 		buzzrunning = 1
 		while buzzrunning == 1:
@@ -244,11 +259,12 @@ class BuzzIn:
 				boxcounter = 3
 			elif mousepos[1] > qobj.num4rect.top and mousepos[1] < qobj.num4rect.bottom:
 				boxcounter = 4				
-			background.fill((0,0,0))
+			background.fill(bgcolor)
 			screen.blit(background, (0,0))
 			qobj.drawselection(boxcounter)
-			qobj.drawscore(p1s, p2s, p3s, "yes", buzz)
+			qobj.drawscore(p1s, p2s, p3s,1 ,buzz)
 			qobj.drawwrong(self.wrong1, self.wrong2, self.wrong3, self.wrong4)
+			qobj.showtime(timeleft)
 			qobj.drawscreen()	
 			pygame.display.flip()
 			pygame.time.wait(10)
@@ -261,24 +277,24 @@ class BuzzIn:
 					if boxcounter == sq.answer:
 						correct.play(0, 2000)
 						self.score += 2
-						self.playerwas = "correct"								
+						self.playerwas = 1							
 					else:
-						if boxcounter == 1 and self.wrong1 == "no":
-							self.wrong1 = "yes"
+						if boxcounter == 1 and self.wrong1 == 0:
+							self.wrong1 = 1
 							self.score -= 1
-							self.playerwas = "wrong"
-						elif boxcounter == 2 and self.wrong2 == "no":
-							self.wrong2 = "yes"
+							self.playerwas = 0
+						elif boxcounter == 2 and self.wrong2 == 0:
+							self.wrong2 = 1
 							self.score -= 1
-							self.playerwas = "wrong"
-						elif boxcounter == 3 and self.wrong3 == "no":
-							self.wrong3 = "yes"
+							self.playerwas = 0
+						elif boxcounter == 3 and self.wrong3 == 0:
+							self.wrong3 = 1
 							self.score -= 1
-							self.playerwas = "wrong"
-						elif boxcounter == 4 and self.wrong4 == "no":
-							self.wrong4 = "yes"
+							self.playerwas = 0
+						elif boxcounter == 4 and self.wrong4 == 0:
+							self.wrong4 = 1
 							self.score = self.score - 1
-							self.playerwas = "wrong"
+							self.playerwas = 0
 						wrong.play(0, 2000)	
 					buzzrunning = 0
 
@@ -286,158 +302,183 @@ class BuzzIn:
 					if event.key == K_ESCAPE:
 						self.escape.loop()
 						if self.escape.backtomenu == 1:
-							mehmeh = 0
+							buzzrunning = 0
 						
 					if pygame.key.name(event.key) == str(sq.answer):
 						correct.play(0, 2000)
 						self.score = self.score + 2
-						self.playerwas = "correct"
+						self.playerwas = 1
 						mehmeh = 0
 										
 					else:
 						if pygame.key.name(event.key) == "1" and self.wrong1 == "no":
-							self.wrong1 = "yes"
+							self.wrong1 = 1
 							wrong.play(0, 2000)
 							self.score = self.score - 1
-							self.playerwas = "wrong"
+							self.playerwas = 0
 							mehmeh = 0
 						elif pygame.key.name(event.key) == "2" and self.wrong2 == "no":
-							self.wrong2 = "yes"
+							self.wrong2 = 1
 							wrong.play(0, 2000)
 							self.score = self.score - 1
-							self.playerwas = "wrong"
+							self.playerwas = 0
 							mehmeh = 0
 						elif pygame.key.name(event.key) == "3" and self.wrong3 == "no":
-							self.wrong3 = "yes"	
+							self.wrong3 = 1	
 							wrong.play(0, 2000)
 							self.score = self.score - 1
-							self.playerwas = "wrong"
+							self.playerwas = 0
 							mehmeh = 0
 						elif pygame.key.name(event.key) == "4" and self.wrong4 == "no":
-							self.wrong4 = "yes"
+							self.wrong4 = 1
 							wrong.play(0, 2000)
 							self.score = self.score - 1
-							self.playerwas = "wrong"
+							self.playerwas = 0
 							mehmeh = 0
 						
 										
 class LoopQuestion:
-	def __init__(self, screen, background, categorychoice, p1s, p2s, p3s, numplayers):
+	def __init__(self, screen, background, categorychoice, p1s, p2s, p3s, numplayers, roundnum):
 		self.p1score_q = p1s; self.p2score_q =p2s; self.p3score_q = p3s
 		self.numplayers = numplayers
 		
-		bi = "None"
-		wrong1 = "no"; wrong2 = "no"; wrong3 = "no"; wrong4 = "no"
-		p1try = "no"; p2try = "no"; p3try = "no"
+		bi = 0
+
+		wrong1 = 0; wrong2 = 0; wrong3 = 0; wrong4 = 0
+		p1try = 0; p2try = 0; p3try = 0
 		self.backtomenu = 0
 		totaltries = 0
 		answered = 0
 		self.whowasright = 0
 		
 		sq = SetQuestion(categorychoice)
-		mq = MakeQuestion(screen, background, sq.question, sq.choice1, sq.choice2, sq.choice3, sq.choice4, sq.sound, numplayers)
+		mq = MakeQuestion(screen, background, sq.question, sq.choice1, sq.choice2, sq.choice3, sq.choice4, sq.sound, numplayers, roundnum)
 		mq.playquestion()
 		escape = Esc(screen, background)
 		
-		timestart = pygame.time.get_ticks()
-		esctime = 0
+		t_0 = pygame.time.get_ticks()
+		t_sound_0 = pygame.time.get_ticks()
+		
+		t_now = 0
+		t_pause = 0
+		t_sound_pause = 0
+		
+		timeleft = 21000
+		playtick = 1
 		
 		running = 1
 		while (running==1):
-			background.fill(black)
+			background.fill(bgcolor)
 			screen.blit(background, (0,0))
 			mq.drawwrong(wrong1, wrong2, wrong3, wrong4)
 			mq.drawscreen()
-			mq.drawscore(p1s, p2s, p3s, "no", 0)
+			mq.drawscore(p1s, p2s, p3s, 0, 0)
+			mq.showtime(timeleft)
 			pygame.display.flip()
 			pygame.time.wait(10)
+			
+			t_now = pygame.time.get_ticks() - t_0
+			timeleft = 21000 - (t_now - t_pause)
 		
-			timetotal = pygame.time.get_ticks()
-			timedelta = timetotal - timestart + esctime
-			if timedelta >= 20000:
+			if timeleft <= 0:
 				running = 0
 			
+			t_sound_now = pygame.time.get_ticks()
+			t_sound_delta = t_sound_now - t_sound_0
+			t_sound = 1000.0 - (t_sound_delta - t_sound_pause)
+			
+			if t_sound <= 0:
+				if playtick == 1:
+					tick.play(0,0)
+					playtick = 0
+				else:
+					tock.play(0,0)
+					playtick = 1
+				t_sound_0 = pygame.time.get_ticks()
+				t_sound_pause = 0
+			
 			for event in pygame.event.get():
 				if event.type is KEYDOWN:
+					
+					t_pause_in = pygame.time.get_ticks()
 					mq.stopquestion()
-					if (pygame.key.name(event.key) == p1buzz or event.key == K_LSHIFT) and p1try == "no" and int(numplayers) >= 1:
+					if (pygame.key.name(event.key) == (p1buzz or event.key == K_LSHIFT) and p1try == 0 and numplayers >= 1):
 						buzz.play(0, 2000)
-						bi = BuzzIn(screen, background, mq, sq, wrong1, wrong2, wrong3, wrong4, p1s, p2s, p3s, 1)
-						if bi.playerwas == "wrong":
+						bi = BuzzIn(screen, background, mq, sq, wrong1, wrong2, wrong3, wrong4, p1s, p2s, p3s, 1, timeleft)
+						if bi.playerwas == 0:
 							totaltries = totaltries + 1
-							p1try = "yes"
+							p1try = 1
 							wrong1 = bi.wrong1; wrong2 = bi.wrong2; wrong3 = bi.wrong3; wrong4 = bi.wrong4
 							p1s = p1s + bi.score
-						if bi.playerwas == "correct":
+						if bi.playerwas == 1:
 							answered = 1
 							p1s = p1s + bi.score
 							self.whowasright = 1
-						pygame.init()
-						timestart = pygame.time.get_ticks()
 						
-					elif (pygame.key.name(event.key) == p2buzz or event.key == K_SPACE) and p2try == "no" and int(numplayers) >= 2:
+					elif (pygame.key.name(event.key) == (p2buzz or event.key == K_SPACE) and p2try == 0 and numplayers >= 2):
 						buzz.play(0, 2000)
-						bi = BuzzIn(screen, background, mq, sq, wrong1, wrong2, wrong3, wrong4, p1s, p2s, p3s, 2)
-						if bi.playerwas == "wrong":
+						bi = BuzzIn(screen, background, mq, sq, wrong1, wrong2, wrong3, wrong4, p1s, p2s, p3s, 2, timeleft)
+						if bi.playerwas == 0:
 							totaltries = totaltries + 1
-							p2try = "yes"
+							p2try = 1
 							wrong1 = bi.wrong1; wrong2 = bi.wrong2; wrong3 = bi.wrong3; wrong4 = bi.wrong4
 							p2s = p2s + bi.score
-						if bi.playerwas == "correct":
+						if bi.playerwas == 1:
 							answered = 1
 							p2s = p2s + bi.score
 							self.whowasright = 2
-						pygame.init()
-						timestart = pygame.time.get_ticks()
 							
-					elif (pygame.key.name(event.key) == p3buzz or event.key == K_RSHIFT) and p3try == "no" and int(numplayers) >= 3:
+					elif (pygame.key.name(event.key) == (p3buzz or event.key == K_RSHIFT) and p3try == 0 and numplayers >= 3):
 						buzz.play(0, 2000)
-						bi = BuzzIn(screen, background, mq, sq, wrong1, wrong2, wrong3, wrong4, p1s, p2s, p3s, 3)
-						if bi.playerwas == "wrong":
-							totaltries = totaltries + 1	
-							p3try = "yes"
+						
+						bi = BuzzIn(screen, background, mq, sq, wrong1, wrong2, wrong3, wrong4, p1s, p2s, p3s, 3, timeleft)
+						if bi.playerwas == 0:	
+							totaltries = totaltries + 1
+							p3try = 1
 							wrong1 = bi.wrong1; wrong2 = bi.wrong2; wrong3 = bi.wrong3; wrong4 = bi.wrong4
 							p3s = p3s + bi.score
-						if bi.playerwas == "correct":
+						if bi.playerwas == 1:
 							answered = 1
 							p3s = p3s + bi.score
 							self.whowasright = 3
-						pygame.init()
-						timestart = pygame.time.get_ticks()
 							
-					elif event.key == K_ESCAPE and answered != 1 and totaltries < int(self.numplayers):
+					elif (event.key == K_ESCAPE and answered != 1 and totaltries < self.numplayers):
 						escape.loop()
-						esctime = timedelta
-						pygame.init()
-						timestart = pygame.time.get_ticks()
+					t_pause_out = pygame.time.get_ticks()
+					t_pause += (t_pause_out - t_pause_in)
+					t_sound_pause += (t_pause_out - t_pause_in)
 					
 				if event.type is QUIT:
 					sys.exit()
+					
 			if totaltries >= int(self.numplayers):
 				self.p1score_q = p1s; self.p2score_q = p2s; self.p3score_q = p3s
-				background.fill(black)
+				background.fill(bgcolor)
 				screen.blit(background, (0,0))
 				mq.drawwrong(wrong1, wrong2, wrong3, wrong4)
 				mq.drawscreen()	
-				mq.drawscore(p1s, p2s, p3s, "no", 0)
+				mq.drawscore(p1s, p2s, p3s, 0, 0)
+				mq.showtime(timeleft)
 				pygame.display.flip()
 				pygame.time.wait(1000)
 				running = 0
 			if answered == 1:
 				self.p1score_q = p1s; self.p2score_q = p2s; self.p3score_q = p3s
-				background.fill(black)
+				background.fill(bgcolor)
 				screen.blit(background, (0,0))
 				mq.drawcorrect(sq.answer)
 				mq.drawwrong(wrong1, wrong2, wrong3, wrong4)
 				mq.drawscreen()	
-				mq.drawscore(p1s, p2s, p3s, "no", 0)
+				mq.drawscore(p1s, p2s, p3s, 0, 0)
+				mq.showtime(timeleft)
 				pygame.display.flip()
 				pygame.time.wait(1000)
 				running = 0
 				
 			self.backtomenu = escape.backtomenu
 			if self.backtomenu == 1: running = 0
-			if bi != "None":
+			
+			if bi != 0:
 				if bi.escape.backtomenu == 1: 
 					self.backtomenu = 1 
 					running = 0
\ No newline at end of file
