@@ -1,5 +1,5 @@
-#PySciTrivia version 0.10
-#Copyright 2005, Michael Atkinson
+#PySciTrivia 0.02
+#Copyright (C) 2005, 2006 Michael Atkinson
 
 #This file is part of PySciTrivia.
 
@@ -17,38 +17,24 @@
 #along with PySciTrivia; if not, write to the Free Software
 #Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-#import python modules
 import os, sys, pygame, random, math
 from pygame.locals import *
 
-#add the PySciTrivia modules folder to be searched for modules
 sys.path.append('modules')
 
-#import from the appended path in the local modules directory
 from scale import windowset
 from menu import LoopMenu
 
-#initialize pygame
 pygame.init()
 
-#create window from scale module
 window = windowset
-
-#set the window caption
-pygame.display.set_caption('PySciTrivia') 
+pygame.display.set_caption('PySciTrivia 0.02') 
 
 #special surface that represents the screen user actually sees
 screen = pygame.display.get_surface()
 
-#surface filled black which we'll use to clear the screen
+#background surface
 background = pygame.Surface(screen.get_size())
-background.fill((0, 0, 0))
-
-#draw the background surface to our real surface
-screen.blit(background, (0, 0))
-
-#updates screen
-pygame.display.flip()
 
 #start the menu
 LoopMenu(screen, background)
\ No newline at end of file
